@@ -8,7 +8,7 @@ This module contains unit tests for the prerequisite functions in the amd-debug-
 import logging
 import unittest
 import subprocess
-from unittest.mock import patch, MagicMock
+from unittest.mock import patch, MagicMock, mock_open
 
 from amd_debug.prerequisites import PrerequisiteValidator
 from amd_debug.failures import *
@@ -143,6 +143,16 @@ class TestPrerequisiteValidator(unittest.TestCase):
         result = self.validator.check_port_pm_override()
         self.assertTrue(result)
 
+    @patch("amd_debug.prerequisites.version.parse")
+    def test_check_port_pm_override_smu_version_missing(self, mock_version_parse):
+        """Test check_port_pm_override with SMU version undefined"""
+        self.validator.cpu_family = 0x19
+        self.validator.cpu_model = 0x74
+        mock_version_parse.side_effect = lambda v: v if isinstance(v, str) else None
+        self.validator.smu_version = ""
+        result = self.validator.check_port_pm_override()
+        self.assertTrue(result)
+
     @patch("amd_debug.prerequisites.version.parse")
     def test_check_port_pm_override_smu_version_too_low(self, mock_version_parse):
         """Test check_port_pm_override with SMU version < 76.18.0"""
@@ -180,20 +190,25 @@ class TestPrerequisiteValidator(unittest.TestCase):
         self.assertTrue(result)
         self.mock_db.record_prereq.assert_called_with("IOMMU disabled", "✅")
 
-    def test_check_iommu_no_dma_protection(self):
-        """Test check_iommu when DMA protection is not enabled"""
+    @patch(
+        "amd_debug.prerequisites.open",
+        new_callable=unittest.mock.mock_open,
+        read_data=b"\x00" * 45,
+    )
+    @patch("amd_debug.prerequisites.os.path.exists", return_value=True)
+    def test_check_iommu_no_dma_protection_no_msft0201(self, _mock_open, _mock_exists):
+        """Test check_iommu when DMA protection is not enabled and no MSFT0201 in IVRS"""
         self.validator.cpu_family = 0x1A
         self.validator.cpu_model = 0x20
         iommu_device = MagicMock(sys_path="/sys/devices/iommu")
-        thunderbolt_device = MagicMock(sys_path="/sys/devices/thunderbolt")
+        acpi_device = MagicMock(sys_path="/sys/devices/acpi/MSFT0201")
+        platform_device = MagicMock(sys_path="/sys/devices/platform/MSFT0201")
         self.mock_pyudev.list_devices.side_effect = [
             [iommu_device],
-            [thunderbolt_device],
-            [],
-            [],
+            [acpi_device],
+            [platform_device],
         ]
-        with patch("amd_debug.prerequisites.read_file", return_value="0"):
-            result = self.validator.check_iommu()
+        result = self.validator.check_iommu()
         self.assertFalse(result)
         self.assertTrue(
             any(isinstance(f, DMArNotEnabled) for f in self.validator.failures)
@@ -202,20 +217,43 @@ class TestPrerequisiteValidator(unittest.TestCase):
             "IOMMU is misconfigured: Pre-boot DMA protection not enabled", "❌"
         )
 
-    def test_check_iommu_missing_acpi_device(self):
+    @patch(
+        "amd_debug.prerequisites.open",
+        new_callable=unittest.mock.mock_open,
+        read_data=b"\x00" * 45 + "MSFT0201".encode("utf-8"),
+    )
+    @patch("amd_debug.prerequisites.os.path.exists", return_value=True)
+    def test_check_iommu_no_dma_protection_BUT_msft0201(self, _mock_open, _mock_exists):
+        """Test check_iommu when DMA protection is not enabled BUT MSFT0201 is in IVRS"""
+        self.validator.cpu_family = 0x1A
+        self.validator.cpu_model = 0x20
+        iommu_device = MagicMock(sys_path="/sys/devices/iommu")
+        acpi_device = MagicMock(sys_path="/sys/devices/acpi/MSFT0201")
+        platform_device = MagicMock(sys_path="/sys/devices/platform/MSFT0201")
+        self.mock_pyudev.list_devices.side_effect = [
+            [iommu_device],
+            [acpi_device],
+            [platform_device],
+        ]
+        result = self.validator.check_iommu()
+        self.assertTrue(result)
+
+    @patch(
+        "amd_debug.prerequisites.open",
+        new_callable=unittest.mock.mock_open,
+        read_data=b"\x00" * 36 + b"\xff" * 4,
+    )
+    def test_check_iommu_missing_acpi_device(self, _mock_open):
         """Test check_iommu when MSFT0201 ACPI device is missing"""
         self.validator.cpu_family = 0x1A
         self.validator.cpu_model = 0x20
         iommu_device = MagicMock(sys_path="/sys/devices/iommu")
-        thunderbolt_device = MagicMock(sys_path="/sys/devices/thunderbolt")
         self.mock_pyudev.list_devices.side_effect = [
             [iommu_device],
-            [thunderbolt_device],
             [],
             [],
         ]
-        with patch("amd_debug.prerequisites.read_file", return_value="1"):
-            result = self.validator.check_iommu()
+        result = self.validator.check_iommu()
         self.assertFalse(result)
         self.assertTrue(
             any(isinstance(f, MissingIommuACPI) for f in self.validator.failures)
@@ -224,47 +262,48 @@ class TestPrerequisiteValidator(unittest.TestCase):
             "IOMMU is misconfigured: missing MSFT0201 ACPI device", "❌"
         )
 
-    def test_check_iommu_missing_policy(self):
+    @patch(
+        "amd_debug.prerequisites.open",
+        new_callable=unittest.mock.mock_open,
+        read_data=b"\x00" * 36 + b"\xff" * 4,
+    )
+    def test_check_iommu_missing_policy(self, _mock_open):
         """Test check_iommu when policy is not bound to MSFT0201"""
         self.validator.cpu_family = 0x1A
         self.validator.cpu_model = 0x20
         iommu_device = MagicMock(sys_path="/sys/devices/iommu")
-        thunderbolt_device = MagicMock(sys_path="/sys/devices/thunderbolt")
         acpi_device = MagicMock(sys_path="/sys/devices/acpi/MSFT0201")
         platform_device = MagicMock(sys_path="/sys/devices/platform/MSFT0201")
         self.mock_pyudev.list_devices.side_effect = [
             [iommu_device],
-            [thunderbolt_device],
             [acpi_device],
             [platform_device],
         ]
-        with patch("amd_debug.prerequisites.read_file", return_value="1"), patch(
-            "os.path.exists", return_value=False
-        ):
-            result = self.validator.check_iommu()
+        result = self.validator.check_iommu()
         self.assertFalse(result)
         self.assertTrue(
             any(isinstance(f, MissingIommuPolicy) for f in self.validator.failures)
         )
 
-    def test_check_iommu_properly_configured(self):
+    @patch(
+        "amd_debug.prerequisites.open",
+        new_callable=unittest.mock.mock_open,
+        read_data=b"\x00" * 36 + b"\xff" * 4,
+    )
+    @patch("amd_debug.prerequisites.os.path.exists", return_value=True)
+    def test_check_iommu_properly_configured(self, _mock_open, _mock_exists):
         """Test check_iommu when IOMMU is properly configured"""
         self.validator.cpu_family = 0x1A
         self.validator.cpu_model = 0x20
         iommu_device = MagicMock(sys_path="/sys/devices/iommu")
-        thunderbolt_device = MagicMock(sys_path="/sys/devices/thunderbolt")
         acpi_device = MagicMock(sys_path="/sys/devices/acpi/MSFT0201")
         platform_device = MagicMock(sys_path="/sys/devices/platform/MSFT0201")
         self.mock_pyudev.list_devices.side_effect = [
             [iommu_device],
-            [thunderbolt_device],
             [acpi_device],
             [platform_device],
         ]
-        with patch("amd_debug.prerequisites.read_file", return_value="1"), patch(
-            "os.path.exists", return_value=True
-        ):
-            result = self.validator.check_iommu()
+        result = self.validator.check_iommu()
         self.assertTrue(result)
         self.mock_db.record_prereq.assert_called_with("IOMMU properly configured", "✅")
 
@@ -287,7 +326,7 @@ class TestPrerequisiteValidator(unittest.TestCase):
             BIT(9) | 1
         )  # Kernel warnings ignored, other taint present
         result = self.validator.check_taint()
-        self.assertFalse(result)
+        self.assertTrue(result)
         self.assertTrue(
             any(isinstance(f, TaintedKernel) for f in self.validator.failures)
         )
@@ -495,9 +534,7 @@ class TestPrerequisiteValidator(unittest.TestCase):
         result = self.validator.map_acpi_path()
         self.assertTrue(result)
         self.mock_db.record_debug.assert_called_with(
-            "ACPI name: ACPI path [driver]\n"
-            "│ device1: mocked_path [driver]\n"
-            "└─device2: mocked_path [driver]\n"
+            "ACPI name | ACPI path | Kernel driver\ndevice1 | mocked_path | driver\ndevice2 | mocked_path | driver\n"
         )
 
     @patch("amd_debug.prerequisites.os.path.exists")
@@ -540,7 +577,7 @@ class TestPrerequisiteValidator(unittest.TestCase):
         result = self.validator.map_acpi_path()
         self.assertTrue(result)
         self.mock_db.record_debug.assert_called_with(
-            "ACPI name: ACPI path [driver]\n└─device1: mocked_path [None]\n"
+            "ACPI name | ACPI path | Kernel driver\ndevice1 | mocked_path | None\n"
         )
 
     @patch("amd_debug.prerequisites.read_file")
@@ -564,8 +601,7 @@ class TestPrerequisiteValidator(unittest.TestCase):
 
         self.validator.capture_pci_acpi()
         self.mock_db.record_debug.assert_called_with(
-            "PCI devices\n"
-            "└─0000:00:1f.0 : Intel Corporation ISA bridge [1234abcd] : mocked_acpi_path\n"
+            "PCI Slot | Vendor | Class | ID | ACPI path\n└─0000:00:1f.0 | Intel Corporation | ISA bridge | 1234abcd | mocked_acpi_path\n"
         )
 
     @patch("amd_debug.prerequisites.read_file")
@@ -588,8 +624,7 @@ class TestPrerequisiteValidator(unittest.TestCase):
 
         self.validator.capture_pci_acpi()
         self.mock_db.record_debug.assert_called_with(
-            "PCI devices\n"
-            "└─0000:01:00.0 : NVIDIA Corporation VGA compatible controller [5678efgh]\n"
+            "PCI Slot | Vendor | Class | ID | ACPI path\n└─0000:01:00.0 | NVIDIA Corporation | VGA compatible controller | 5678efgh | \n"
         )
 
     @patch("amd_debug.prerequisites.read_file")
@@ -623,9 +658,7 @@ class TestPrerequisiteValidator(unittest.TestCase):
 
         self.validator.capture_pci_acpi()
         self.mock_db.record_debug.assert_called_with(
-            "PCI devices\n"
-            "│ 0000:00:1f.0 : Intel Corporation ISA bridge [1234abcd] : mocked_acpi_path\n"
-            "└─0000:01:00.0 : NVIDIA Corporation VGA compatible controller [5678efgh] : mocked_acpi_path\n"
+            "PCI Slot | Vendor | Class | ID | ACPI path\n│ 0000:00:1f.0 | Intel Corporation | ISA bridge | 1234abcd | mocked_acpi_path\n└─0000:01:00.0 | NVIDIA Corporation | VGA compatible controller | 5678efgh | mocked_acpi_path\n"
         )
 
     def test_capture_pci_acpi_no_devices(self):
@@ -633,7 +666,9 @@ class TestPrerequisiteValidator(unittest.TestCase):
         self.mock_pyudev.list_devices.return_value = []
 
         self.validator.capture_pci_acpi()
-        self.mock_db.record_debug.assert_called_with("PCI devices\n")
+        self.mock_db.record_debug.assert_called_with(
+            "PCI Slot | Vendor | Class | ID | ACPI path\n"
+        )
 
     @patch("amd_debug.prerequisites.read_file")
     def test_check_aspm_default_policy(self, mock_read_file):
@@ -797,8 +832,7 @@ class TestPrerequisiteValidator(unittest.TestCase):
         self.assertFalse(result)
         self.assertTrue(any(isinstance(f, FadtWrong) for f in self.validator.failures))
 
-    @patch("amd_debug.prerequisites.os.path.exists", return_value=False)
-    def test_check_fadt_file_not_found(self, mock_path_exists):
+    def test_check_fadt_file_not_found(self):
         """Test check_fadt when FADT file is not found"""
         self.mock_kernel_log.match_line.return_value = False
         result = self.validator.check_fadt()
@@ -1001,7 +1035,7 @@ class TestPrerequisiteValidator(unittest.TestCase):
             "MockVendor MockProduct (MockFamily)", "💻"
         )
         self.mock_db.record_debug.assert_called_with(
-            "DMI data:\nchassis_type: Desktop\n"
+            "DMI|value\nchassis_type| Desktop\n"
         )
 
     @patch("amd_debug.prerequisites.os.walk")
@@ -1029,7 +1063,7 @@ class TestPrerequisiteValidator(unittest.TestCase):
         self.mock_db.record_prereq.assert_called_with(
             "MockVendor MockProduct (MockFamily)", "💻"
         )
-        self.mock_db.record_debug.assert_called_with("DMI data:\n")
+        self.mock_db.record_debug.assert_called_with("DMI|value\n")
 
     @patch("amd_debug.prerequisites.os.walk")
     @patch("amd_debug.prerequisites.read_file")
@@ -1705,9 +1739,6 @@ class TestPrerequisiteValidator(unittest.TestCase):
         ]
         result = self.validator.check_storage()
         self.assertTrue(result)
-        self.mock_db.record_debug.assert_called_with(
-            "New enough kernel to avoid NVME check"
-        )
 
     def test_check_storage_no_kernel_log(self):
         """Test check_storage when kernel log is unavailable"""
@@ -1737,7 +1768,7 @@ class TestPrerequisiteValidator(unittest.TestCase):
         result = self.validator.capture_edid()
         self.assertTrue(result)
         self.mock_db.record_prereq.assert_called_with(
-            "edid-decode not installed, unable to decode EDID", "👀"
+            "Failed to capture EDID table", "👀"
         )
 
     @patch("amd_debug.prerequisites.subprocess.check_output")
@@ -1750,9 +1781,9 @@ class TestPrerequisiteValidator(unittest.TestCase):
             returncode=1, cmd="edid-decode", output=b"Error decoding EDID"
         )
         result = self.validator.capture_edid()
-        self.assertFalse(result)
+        self.assertTrue(result)
         self.mock_db.record_prereq.assert_called_with(
-            "Failed to capture EDID table: b'Error decoding EDID'", "👀"
+            "Failed to capture EDID table", "👀"
         )
 
     @patch("amd_debug.prerequisites.subprocess.check_output")
@@ -1767,3 +1798,240 @@ class TestPrerequisiteValidator(unittest.TestCase):
         self.mock_db.record_debug.assert_called_with(
             apply_prefix_wrapper("EDID for Monitor1:", "Decoded EDID data")
         )
+
+    @patch("amd_debug.prerequisites.find_ip_version", return_value=True)
+    @patch("amd_debug.prerequisites.os.path.exists")
+    @patch("amd_debug.prerequisites.read_file")
+    def test_check_dpia_pg_dmcub_usb4_found(
+        self, mock_read_file, mock_path_exists, mock_find_ip_version
+    ):
+        """Test check_dpia_pg_dmcub when USB4 routers are found"""
+        usb4_device = MagicMock()
+        self.mock_pyudev.list_devices.side_effect = [
+            [usb4_device],  # First call: USB4 present
+        ]
+        result = self.validator.check_dpia_pg_dmcub()
+        self.assertTrue(result)
+        self.mock_db.record_debug.assert_called_with(
+            "USB4 routers found, no need to check DMCUB version"
+        )
+
+    @patch("amd_debug.prerequisites.find_ip_version", return_value=True)
+    @patch("amd_debug.prerequisites.os.path.exists", return_value=True)
+    @patch("amd_debug.prerequisites.read_file", return_value="0x90001B01")
+    def test_check_dpia_pg_dmcub_dmcub_fw_version_new_enough(
+        self, mock_read_file, mock_path_exists, mock_find_ip_version
+    ):
+        """Test check_dpia_pg_dmcub when DMCUB firmware version is new enough"""
+        self.mock_pyudev.list_devices.side_effect = [
+            [],  # First call: no USB4
+            [
+                MagicMock(
+                    properties={
+                        "PCI_CLASS": "30000",
+                        "PCI_ID": "1002abcd",
+                        "PCI_SLOT_NAME": "0000:01:00.0",
+                    },
+                    sys_path="/sys/devices/pci0000:01/0000:01:00.0",
+                )
+            ],
+        ]
+        with patch("builtins.open", new_callable=mock_open, read_data="3") as mock_file:
+            handlers = (
+                mock_file.return_value,
+                mock_open(read_data="5").return_value,
+                mock_open(read_data="0").return_value,
+            )
+            mock_open.side_effect = handlers
+            result = self.validator.check_dpia_pg_dmcub()
+        self.assertTrue(result)
+        self.mock_db.record_prereq.assert_not_called()
+
+    @patch("amd_debug.prerequisites.find_ip_version", return_value=True)
+    @patch("amd_debug.prerequisites.os.path.exists", return_value=True)
+    @patch("amd_debug.prerequisites.read_file", return_value="0x8001B00")
+    def test_check_dpia_pg_dmcub_dmcub_fw_version_too_old(
+        self, mock_read_file, mock_path_exists, mock_find_ip_version
+    ):
+        """Test check_dpia_pg_dmcub when DMCUB firmware version is too old"""
+        self.mock_pyudev.list_devices.side_effect = [
+            [],  # First call: no USB4
+            [
+                MagicMock(
+                    properties={
+                        "PCI_CLASS": "30000",
+                        "PCI_ID": "1002abcd",
+                        "PCI_SLOT_NAME": "0000:01:00.0",
+                    },
+                    sys_path="/sys/devices/pci0000:01/0000:01:00.0",
+                )
+            ],
+        ]
+        result = self.validator.check_dpia_pg_dmcub()
+        self.assertFalse(result)
+        self.mock_db.record_prereq.assert_called_with(
+            "DMCUB Firmware is outdated", "❌"
+        )
+        self.assertTrue(
+            any(isinstance(f, DmcubTooOld) for f in self.validator.failures)
+        )
+
+    @patch("amd_debug.prerequisites.find_ip_version", return_value=True)
+    @patch("amd_debug.prerequisites.os.path.exists", return_value=False)
+    @patch(
+        "amd_debug.prerequisites.read_file",
+        side_effect=[
+            "",  # sysfs read returns empty, so fallback to debugfs
+            "DMCUB fw: 09001B00\nOther line\n",  # debugfs read
+        ],
+    )
+    def test_check_dpia_pg_dmcub_debugfs_version_new_enough(
+        self, mock_read_file, mock_path_exists, mock_find_ip_version
+    ):
+        """Test check_dpia_pg_dmcub when DMCUB version is found in debugfs and is new enough"""
+        self.mock_pyudev.list_devices.side_effect = [
+            [],  # First call: no USB4
+            [
+                MagicMock(
+                    properties={
+                        "PCI_CLASS": "30000",
+                        "PCI_ID": "1002abcd",
+                        "PCI_SLOT_NAME": "0",
+                    },
+                    sys_path="/sys/devices/pci0000:01/0000:01:00.0",
+                )
+            ],
+        ]
+        result = self.validator.check_dpia_pg_dmcub()
+        self.assertTrue(result)
+        self.mock_db.record_prereq.assert_not_called()
+
+    @patch("amd_debug.prerequisites.find_ip_version", return_value=True)
+    @patch("amd_debug.prerequisites.os.path.exists", return_value=False)
+    @patch(
+        "amd_debug.prerequisites.read_file",
+        side_effect=[
+            "DMCUB fw: 0x08001B00\nOther line\n",  # debugfs read
+        ],
+    )
+    def test_check_dpia_pg_dmcub_debugfs_version_too_old(
+        self, mock_read_file, mock_path_exists, mock_find_ip_version
+    ):
+        """Test check_dpia_pg_dmcub when DMCUB version is found in debugfs and is too old"""
+        self.mock_pyudev.list_devices.side_effect = [
+            [],  # First call: no USB4
+            [
+                MagicMock(
+                    properties={
+                        "PCI_CLASS": "30000",
+                        "PCI_ID": "1002abcd",
+                        "PCI_SLOT_NAME": "0",
+                    },
+                    sys_path="/sys/devices/pci0000:01/0000:01:00.0",
+                )
+            ],
+        ]
+        result = self.validator.check_dpia_pg_dmcub()
+        self.assertFalse(result)
+        self.mock_db.record_prereq.assert_called_with(
+            "DMCUB Firmware is outdated", "❌"
+        )
+        self.assertTrue(
+            any(isinstance(f, DmcubTooOld) for f in self.validator.failures)
+        )
+
+    @patch("amd_debug.prerequisites.find_ip_version", return_value=False)
+    def test_check_dpia_pg_dmcub_no_matching_dcn(self, mock_find_ip_version):
+        """Test check_dpia_pg_dmcub when no matching DCN is found"""
+        self.mock_pyudev.list_devices.side_effect = [
+            [],  # First call: no USB4
+            [
+                MagicMock(
+                    properties={
+                        "PCI_CLASS": "30000",
+                        "PCI_ID": "1002abcd",
+                        "PCI_SLOT_NAME": "0",
+                    },
+                    sys_path="/sys/devices/pci0000:01/0000:01:00.0",
+                )
+            ],
+        ]
+        result = self.validator.check_dpia_pg_dmcub()
+        self.assertTrue(result)
+        self.mock_db.record_prereq.assert_not_called()
+
+    @patch("amd_debug.prerequisites.os.path.exists")
+    def test_capture_nvidia_version_file_missing(self, mock_exists):
+        """Test capture_nvidia when /proc/driver/nvidia/version does not exist"""
+        mock_exists.side_effect = lambda p: False if "version" in p else True
+        result = self.validator.capture_nvidia()
+        self.assertTrue(result)
+        self.mock_db.record_debug_file.assert_not_called()
+        self.mock_db.record_prereq.assert_not_called()
+
+    @patch("amd_debug.prerequisites.os.path.exists")
+    def test_capture_nvidia_gpus_dir_missing(self, mock_exists):
+        """Test capture_nvidia when /proc/driver/nvidia/gpus does not exist"""
+
+        def exists_side_effect(path):
+            if "version" in path:
+                return True
+            if "gpus" in path:
+                return False
+            return True
+
+        mock_exists.side_effect = exists_side_effect
+        result = self.validator.capture_nvidia()
+        self.assertTrue(result)
+        self.mock_db.record_debug_file.assert_called_once_with(
+            "/proc/driver/nvidia/version"
+        )
+        self.mock_db.record_prereq.assert_not_called()
+
+    @patch("amd_debug.prerequisites.os.walk")
+    @patch("amd_debug.prerequisites.os.path.exists")
+    def test_capture_nvidia_success(self, mock_exists, mock_walk):
+        """Test capture_nvidia when NVIDIA GPU files are present and readable"""
+        mock_exists.side_effect = lambda p: True
+        mock_walk.return_value = [
+            ("/proc/driver/nvidia/gpus/0000:01:00.0", [], ["info", "power"])
+        ]
+        result = self.validator.capture_nvidia()
+        self.assertTrue(result)
+        self.mock_db.record_debug_file.assert_any_call("/proc/driver/nvidia/version")
+        self.mock_db.record_debug.assert_any_call("NVIDIA info")
+        self.mock_db.record_debug_file.assert_any_call(
+            "/proc/driver/nvidia/gpus/0000:01:00.0/info"
+        )
+        self.mock_db.record_debug.assert_any_call("NVIDIA power")
+        self.mock_db.record_debug_file.assert_any_call(
+            "/proc/driver/nvidia/gpus/0000:01:00.0/power"
+        )
+
+    @patch("amd_debug.prerequisites.os.walk")
+    @patch("amd_debug.prerequisites.os.path.exists")
+    def test_capture_nvidia_permission_error_on_version(self, mock_exists, mock_walk):
+        """Test capture_nvidia when PermissionError occurs reading version file"""
+        mock_exists.side_effect = lambda p: True if "version" in p else False
+        self.mock_db.record_debug_file.side_effect = PermissionError
+        result = self.validator.capture_nvidia()
+        self.assertTrue(result)
+        self.mock_db.record_prereq.assert_called_with(
+            "NVIDIA GPU version not readable", "👀"
+        )
+
+    @patch("amd_debug.prerequisites.os.walk")
+    @patch("amd_debug.prerequisites.os.path.exists")
+    def test_capture_nvidia_permission_error_on_gpu_file(self, mock_exists, mock_walk):
+        """Test capture_nvidia when PermissionError occurs reading a GPU file"""
+        mock_exists.side_effect = lambda p: True
+        mock_walk.return_value = [
+            ("/proc/driver/nvidia/gpus/0000:01:00.0", [], ["info"])
+        ]
+        self.mock_db.record_debug_file.side_effect = [None, PermissionError]
+        result = self.validator.capture_nvidia()
+        self.assertTrue(result)
+        self.mock_db.record_debug.assert_any_call("NVIDIA info")
+        self.mock_db.record_prereq.assert_called_with(
+            "NVIDIA GPU {f} not readable", "👀"
+        )
