@@ -117,9 +117,9 @@ class TestParseArgs(unittest.TestCase):
 
     def test_version_command(self):
         """Test parse_args with version command"""
-        sys.argv = ["s2idle.py", "version"]
+        sys.argv = ["s2idle.py", "--version"]
         args = parse_args()
-        self.assertEqual(args.action, "version")
+        self.assertTrue(args.version)
 
 
 class TestMainFunction(unittest.TestCase):
@@ -180,7 +180,7 @@ class TestMainFunction(unittest.TestCase):
             mock_report.assert_called_once_with(
                 "2023-01-01", "2023-02-01", None, "html", False, False
             )
-            self.assertTrue(result)
+            self.assertIsNone(result)
 
     @patch("amd_debug.s2idle.relaunch_sudo")
     @patch("amd_debug.s2idle.run_test_cycle")
@@ -207,26 +207,28 @@ class TestMainFunction(unittest.TestCase):
             mock_test.assert_called_once_with(
                 None, None, "5", "txt", None, False, False, False, False, False
             )
-            self.assertTrue(result)
+            self.assertIsNone(result)
 
     @patch("amd_debug.s2idle.version")
     def test_main_version(self, mock_version):
         """Test main function with version action"""
         sys.argv = ["s2idle.py", "version"]
         with patch("amd_debug.s2idle.parse_args") as mock_parse_args:
-            mock_parse_args.return_value = argparse.Namespace(action="version")
+            mock_parse_args.return_value = argparse.Namespace(version=True, action=None)
             mock_version.return_value = "1.0.0"
             with patch("builtins.print") as mock_print:
                 result = main()
                 mock_version.assert_called_once()
                 mock_print.assert_called_once_with("1.0.0")
-                self.assertTrue(result)
+                self.assertIsNone(result)
 
     def test_main_no_action(self):
         """Test main function with no action specified"""
         sys.argv = ["s2idle.py"]
         with patch("amd_debug.s2idle.parse_args") as mock_parse_args:
-            mock_parse_args.return_value = argparse.Namespace(action=None)
+            mock_parse_args.return_value = argparse.Namespace(
+                version=False, action=None
+            )
             with self.assertRaises(SystemExit) as cm:
                 main()
             self.assertEqual(cm.exception.code, "no action specified")
@@ -381,6 +383,7 @@ class TestTestFunction(unittest.TestCase):
             "2023-02-01",
             "report.html",
             "html",
+            True,
         )
 
         mock_sleep_validator_instance = mock_sleep_validator.return_value
@@ -454,12 +457,18 @@ class TestTestFunction(unittest.TestCase):
 
     @patch("amd_debug.s2idle.Installer")
     @patch("amd_debug.s2idle.PrerequisiteValidator")
-    @patch("amd_debug.prerequisites.SleepDatabase")
-    @patch("amd_debug.validator.SleepDatabase")
+    @patch("amd_debug.s2idle.SleepValidator")
+    @patch("amd_debug.s2idle.SleepReport")
+    @patch("amd_debug.s2idle.prompt_test_arguments")
+    @patch("amd_debug.s2idle.prompt_report_arguments")
+    @patch("amd_debug.s2idle.display_report_file")
     def test_test_prerequisite_failure(
         self,
-        _mock_sleep_db,
-        _mock_sleep_db_prerequisite,
+        mock_display_report_file,
+        mock_prompt_report_arguments,
+        mock_prompt_test_arguments,
+        mock_sleep_report,
+        mock_sleep_validator,
         mock_prerequisite_validator,
         mock_installer,
     ):
@@ -470,6 +479,17 @@ class TestTestFunction(unittest.TestCase):
         mock_prerequisite_instance = mock_prerequisite_validator.return_value
         mock_prerequisite_instance.run.return_value = False
 
+        mock_prompt_test_arguments.return_value = (10, 5, 3)
+        mock_prompt_report_arguments.return_value = (
+            "2023-01-01",
+            "2023-02-01",
+            "report.html",
+            "html",
+            True,
+        )
+        mock_sleep_validator_instance = mock_sleep_validator.return_value
+        mock_sleep_report_instance = mock_sleep_report.return_value
+
         result = run_test_cycle(
             duration=None,
             wait=None,
@@ -491,7 +511,20 @@ class TestTestFunction(unittest.TestCase):
         mock_prerequisite_validator.assert_called_once_with(True)
         mock_prerequisite_instance.run.assert_called_once()
         mock_prerequisite_instance.report.assert_called_once()
-        self.assertFalse(result)
+        mock_prompt_test_arguments.assert_called_once_with(None, None, None, False)
+        mock_prompt_report_arguments.assert_called_once()
+        mock_sleep_validator_instance.assert_not_called()
+        mock_sleep_report.assert_called_once_with(
+            since=None,
+            until=None,
+            fname="report.html",
+            fmt="html",
+            tool_debug=True,
+            report_debug=True,
+        )
+        mock_sleep_report_instance.run.assert_called_once()
+        mock_display_report_file.assert_called_once_with("report.html", "html")
+        self.assertTrue(result)
 
     @patch("amd_debug.s2idle.Installer")
     @patch("amd_debug.s2idle.PrerequisiteValidator")
@@ -532,9 +565,9 @@ class TestTestFunction(unittest.TestCase):
             "iasl", "ethtool", "edid-decode"
         )
         mock_installer_instance.install_dependencies.assert_called_once()
-        mock_prerequisite_validator.assert_called_once_with(True)
-        mock_prerequisite_instance.run.assert_called_once()
-        mock_prerequisite_instance.report.assert_called_once()
+        mock_prerequisite_validator.assert_not_called()
+        mock_prerequisite_instance.run.assert_not_called()
+        mock_prerequisite_instance.report.assert_not_called()
         mock_prompt_test_arguments.assert_called_once_with(None, None, None, False)
 
 
@@ -605,6 +638,7 @@ class TestReportFunction(unittest.TestCase):
             "2023-02-01",
             "report.html",
             "html",
+            True,
         )
         mock_sleep_report_instance = mock_sleep_report.return_value
 
@@ -614,10 +648,12 @@ class TestReportFunction(unittest.TestCase):
             fname=None,
             fmt=None,
             tool_debug=True,
-            report_debug=True,
+            report_debug=None,
         )
 
-        mock_prompt_report_arguments.assert_called_once_with(None, None, None, None)
+        mock_prompt_report_arguments.assert_called_once_with(
+            None, None, None, None, None
+        )
         mock_sleep_report.assert_called_once_with(
             since="2023-01-01",
             until="2023-02-01",
@@ -640,10 +676,12 @@ class TestReportFunction(unittest.TestCase):
                 fname=None,
                 fmt=None,
                 tool_debug=True,
-                report_debug=True,
+                report_debug=None,
             )
 
-        mock_prompt_report_arguments.assert_called_once_with(None, None, None, None)
+        mock_prompt_report_arguments.assert_called_once_with(
+            None, None, None, None, None
+        )
 
     @patch("amd_debug.s2idle.prompt_report_arguments")
     @patch(
@@ -659,6 +697,7 @@ class TestReportFunction(unittest.TestCase):
             "2023-02-01",
             "report.html",
             "html",
+            True,
         )
 
         result = report(
@@ -667,10 +706,12 @@ class TestReportFunction(unittest.TestCase):
             fname=None,
             fmt=None,
             tool_debug=True,
-            report_debug=True,
+            report_debug=None,
         )
 
-        mock_prompt_report_arguments.assert_called_once_with(None, None, None, None)
+        mock_prompt_report_arguments.assert_called_once_with(
+            None, None, None, None, None
+        )
         mock_sleep_report.assert_called_once_with(
             since="2023-01-01",
             until="2023-02-01",
@@ -695,6 +736,7 @@ class TestReportFunction(unittest.TestCase):
             "2023-02-01",
             "report.html",
             "html",
+            True,
         )
 
         result = report(
@@ -703,10 +745,12 @@ class TestReportFunction(unittest.TestCase):
             fname=None,
             fmt=None,
             tool_debug=True,
-            report_debug=True,
+            report_debug=None,
         )
 
-        mock_prompt_report_arguments.assert_called_once_with(None, None, None, None)
+        mock_prompt_report_arguments.assert_called_once_with(
+            None, None, None, None, None
+        )
         mock_sleep_report.assert_called_once_with(
             since="2023-01-01",
             until="2023-02-01",
@@ -729,6 +773,7 @@ class TestReportFunction(unittest.TestCase):
             "2023-02-01",
             "report.html",
             "html",
+            True,
         )
         mock_sleep_report_instance = mock_sleep_report.return_value
         mock_sleep_report_instance.run.side_effect = ValueError("Invalid value")
@@ -739,10 +784,12 @@ class TestReportFunction(unittest.TestCase):
             fname=None,
             fmt=None,
             tool_debug=True,
-            report_debug=True,
+            report_debug=None,
         )
 
-        mock_prompt_report_arguments.assert_called_once_with(None, None, None, None)
+        mock_prompt_report_arguments.assert_called_once_with(
+            None, None, None, None, None
+        )
         mock_sleep_report.assert_called_once_with(
             since="2023-01-01",
             until="2023-02-01",
@@ -758,14 +805,14 @@ class TestReportFunction(unittest.TestCase):
 class TestPromptReportArguments(unittest.TestCase):
     """Test prompt_report_arguments function"""
 
-    @patch("builtins.input", side_effect=["2023-01-01", "2023-02-01", "html"])
+    @patch("builtins.input", side_effect=["2023-01-01", "2023-02-01", "html", "true"])
     @patch("amd_debug.s2idle.get_report_file", return_value="report.html")
     @patch("amd_debug.s2idle.get_report_format", return_value="html")
     def test_prompt_report_arguments_success(
         self, mock_get_report_format, mock_get_report_file, _mock_input
     ):
         """Test prompt_report_arguments with valid inputs"""
-        result = prompt_report_arguments(None, None, None, None)
+        result = prompt_report_arguments(None, None, None, None, None)
         self.assertEqual(result[0], datetime(2023, 1, 1))
         self.assertEqual(result[1], datetime(2023, 2, 1))
         self.assertEqual(result[2], "report.html")
@@ -775,33 +822,36 @@ class TestPromptReportArguments(unittest.TestCase):
 
     @patch(
         "builtins.input",
-        side_effect=["invalid-date", "2023-01-01", "2023-02-01", "html"],
+        side_effect=["invalid-date", "2023-01-01", "2023-02-01", "html", "true"],
     )
     @patch("sys.exit")
     def test_prompt_report_arguments_invalid_since_date(self, mock_exit, mock_input):
         """Test prompt_report_arguments with invalid 'since' date"""
         mock_exit.side_effect = SystemExit
         with self.assertRaises(SystemExit):
-            prompt_report_arguments(None, None, None, None)
+            prompt_report_arguments(None, None, None, None, None)
         mock_exit.assert_called_once_with(
             "Invalid date, use YYYY-MM-DD: Invalid isoformat string: 'invalid-date'"
         )
 
     @patch(
         "builtins.input",
-        side_effect=["2023-01-01", "invalid-date", "2023-02-01", "html"],
+        side_effect=["2023-01-01", "invalid-date", "2023-02-01", "html", "true"],
     )
     @patch("sys.exit")
     def test_prompt_report_arguments_invalid_until_date(self, mock_exit, mock_input):
         """Test prompt_report_arguments with invalid 'until' date"""
         mock_exit.side_effect = SystemExit
         with self.assertRaises(SystemExit):
-            prompt_report_arguments(None, None, None, None)
+            prompt_report_arguments(None, None, None, None, None)
         mock_exit.assert_called_once_with(
             "Invalid date, use YYYY-MM-DD: Invalid isoformat string: 'invalid-date'"
         )
 
-    @patch("builtins.input", side_effect=["2023-01-01", "2023-02-01", "invalid-format"])
+    @patch(
+        "builtins.input",
+        side_effect=["2023-01-01", "2023-02-01", "invalid-format", "true"],
+    )
     @patch("amd_debug.s2idle.get_report_format", return_value="html")
     @patch("sys.exit")
     def test_prompt_report_arguments_invalid_format(
@@ -810,11 +860,27 @@ class TestPromptReportArguments(unittest.TestCase):
         """Test prompt_report_arguments with invalid format"""
         mock_exit.side_effect = SystemExit
         with self.assertRaises(SystemExit):
-            prompt_report_arguments(None, None, None, None)
+            prompt_report_arguments(None, None, None, None, None)
         mock_exit.assert_called_once_with("Invalid format: invalid-format")
         mock_get_report_format.assert_called_once()
 
-    @patch("builtins.input", side_effect=["", "", ""])
+    @patch(
+        "builtins.input",
+        side_effect=["2023-01-01", "2023-02-01", "html", "foo_the_bar"],
+    )
+    @patch("amd_debug.s2idle.get_report_format", return_value="html")
+    @patch("sys.exit")
+    def test_prompt_report_arguments_invalid_report(
+        self, mock_exit, mock_get_report_format, mock_input
+    ):
+        """Test prompt_report_arguments with invalid format"""
+        mock_exit.side_effect = SystemExit
+        with self.assertRaises(SystemExit):
+            prompt_report_arguments(None, None, None, None, None)
+        mock_exit.assert_called_once_with("Invalid entry: Foo_the_bar")
+        mock_get_report_format.assert_called_once()
+
+    @patch("builtins.input", side_effect=["", "", "", ""])
     @patch(
         "amd_debug.s2idle.get_report_file",
         return_value="amd-s2idle-report-2023-01-01.html",
@@ -824,10 +890,11 @@ class TestPromptReportArguments(unittest.TestCase):
         self, mock_get_report_format, mock_get_report_file, mock_input
     ):
         """Test prompt_report_arguments with default values"""
-        result = prompt_report_arguments(None, None, None, None)
+        result = prompt_report_arguments(None, None, None, None, None)
         self.assertEqual(datetime.date(result[0]), Defaults.since)
         self.assertEqual(datetime.date(result[1]), Defaults.until)
         self.assertEqual(result[2], "amd-s2idle-report-2023-01-01.html")
         self.assertEqual(result[3], "html")
+        self.assertEqual(result[4], True)
         mock_get_report_file.assert_called_once_with(None, "html")
         mock_get_report_format.assert_called()
